diff -pruN 0.15-3/.github/workflows/testsuite.yml 0.16-1/.github/workflows/testsuite.yml
--- 0.15-3/.github/workflows/testsuite.yml	1970-01-01 00:00:00.000000000 +0000
+++ 0.16-1/.github/workflows/testsuite.yml	2024-04-13 13:31:56.000000000 +0000
@@ -0,0 +1,141 @@
+name: testsuite
+
+on: [push, pull_request]
+
+jobs:
+  ubuntu:
+    env:
+      PERL_USE_UNSAFE_INC: 0
+      AUTHOR_TESTING: 1
+      AUTOMATED_TESTING: 1
+      RELEASE_TESTING: 1
+
+    runs-on: ubuntu-latest
+
+    steps:
+      - uses: actions/checkout@v1
+      - run: perl -V
+      - name: install cpan deps
+        uses: perl-actions/install-with-cpm@v1.3
+        with:
+          install: |
+            Crypt::OpenSSL::Guess
+            Test::More
+            Time::HiRes
+            Test::CPAN::Meta
+            Test::Pod
+            Test::Pod::Coverage
+            Test::CPAN::Changes
+            Test::CheckChanges
+            Class::XSAccessor
+            Text::CSV_XS
+            List::MoreUtils
+            Test::Kwalitee
+      - run: perl Makefile.PL
+      - run: make test
+
+  linux:
+    name: "perl ${{ matrix.perl-version }}"
+    needs: [ubuntu]
+    env:
+      PERL_USE_UNSAFE_INC: 0
+      AUTOMATED_TESTING: 1
+      AUTHOR_TESTING: 0
+      RELEASE_TESTING: 0
+
+    runs-on: ubuntu-latest
+
+    strategy:
+      fail-fast: false
+      matrix:
+        perl-version:
+          [
+            "5.38",
+            "5.36",
+            "5.34",
+            "5.32",
+            "5.30",
+            "5.28",
+            "5.26",
+            "5.24",
+            "5.22",
+            "5.20",
+            "5.18",
+            "5.16",
+            "5.14",
+            "5.12",
+            "5.10",
+            "5.8",
+          ]
+
+    steps:
+      - uses: actions/checkout@v1
+      - uses: shogo82148/actions-setup-perl@v1
+        with:
+          perl-version: ${{ matrix.perl-version }}
+      - run: perl -V
+      - name: install cpan deps
+        uses: perl-actions/install-with-cpm@v1.3
+        with:
+          sudo: false
+          install: |
+            Crypt::OpenSSL::Guess
+            Test::More
+            Time::HiRes
+      - run: perl Makefile.PL
+      - run: make test
+
+  macOS:
+    needs: [ubuntu]
+    env:
+      PERL_USE_UNSAFE_INC: 0
+      AUTOMATED_TESTING: 1
+      AUTHOR_TESTING: 0
+      RELEASE_TESTING: 0
+
+    runs-on: macOS-latest
+
+    strategy:
+      fail-fast: false
+      matrix:
+        perl-version: [latest]
+
+    steps:
+      - uses: actions/checkout@v1
+      - run: perl -V
+      - name: install cpan deps
+        uses: perl-actions/install-with-cpm@v1.3
+        with:
+          sudo: false
+          install: |
+            Crypt::OpenSSL::Guess
+      - run: perl Makefile.PL
+      - run: make test
+
+  windows:
+    needs: [ubuntu]
+    env:
+      PERL_USE_UNSAFE_INC: 0
+      AUTOMATED_TESTING: 1
+      AUTHOR_TESTING: 0
+      RELEASE_TESTING: 0
+      VCPKG_DEFAULT_TRIPLET: x64-windows
+
+    runs-on: windows-latest
+
+    strategy:
+      fail-fast: false
+      matrix:
+        perl-version: [latest]
+
+    steps:
+      - uses: actions/checkout@master
+      - run: perl -V
+      - run: perl Makefile.PL
+      - run: echo $PATH
+        shell: bash
+      #- run: prove -vb t/*.t
+      # https://github.com/actions/runner-images/issues/5459
+      - run: PATH="/c/Strawberry/c/bin:/c/Strawberry/perl/site/bin:/c/Strawberry/perl/bin:/c/ProgramData/Chocolatey/bin:/c/Windows/system32:/c/Windows:/usr/bin:/c/mingw64/bin" make test
+        shell: bash
+        #continue-on-error: true
diff -pruN 0.15-3/.travis.yml 0.16-1/.travis.yml
--- 0.15-3/.travis.yml	1970-01-01 00:00:00.000000000 +0000
+++ 0.16-1/.travis.yml	2024-04-12 16:58:52.000000000 +0000
@@ -0,0 +1,32 @@
+language: perl
+sudo: false
+branches:
+  except:
+    - /issue\d+/
+perl:
+  - 5.8.1
+  - 5.8.3
+  - 5.8.6
+  - 5.8.7
+  - 5.8.8
+  - 5.8.9
+  - 5.10.1
+  - 5.12.3
+  - 5.14.4
+  - 5.16.3
+  - 5.18.4
+  - 5.20.3
+  - 5.22.3
+  - 5.24.2
+  - 5.26.1
+before_install:
+  - export AUTOMATED_TESTING=1
+  - eval $(curl https://travis-perl.github.io/init) --auto
+  - build-perl
+  - perl -V
+  - build-dist
+  - cd $BUILD_DIR
+install:
+  - export AUTOMATED_TESTING=1 HARNESS_TIMER=1 AUTHOR_TESTING=1 RELEASE_TESTING=1
+  - cpanm --notest Crypt::OpenSSL::Guess
+  - cpanm --installdeps --notest .
diff -pruN 0.15-3/.whitesource 0.16-1/.whitesource
--- 0.15-3/.whitesource	1970-01-01 00:00:00.000000000 +0000
+++ 0.16-1/.whitesource	2024-04-12 16:58:52.000000000 +0000
@@ -0,0 +1,8 @@
+{
+  "generalSettings": {
+    "shouldScanRepo": true
+  },
+  "checkRunSettings": {
+    "vulnerableCheckRunConclusionLevel": "failure"
+  }
+}
\ No newline at end of file
diff -pruN 0.15-3/Changes 0.16-1/Changes
--- 0.15-3/Changes	2018-04-22 12:16:39.000000000 +0000
+++ 0.16-1/Changes	2024-04-13 13:36:37.000000000 +0000
@@ -1,5 +1,13 @@
 Revision history for Perl extension Crypt::OpenSSL::Random.
 
+0.16  2024-04-13 rurban
+        - add github actions, travis and appveyor.
+        - Many patches by Takumi Akiyama.
+        - Fix broken github image for strawberry perl
+          by stripping its PATH. their new mingw is incompatible to their
+          old strawberry 5.32
+        - minor documentation fixes.
+
 0.15  2018-04-22 rurban
         - fix mingw hints for pkg-config support (akiym, PR #7)
 
diff -pruN 0.15-3/MANIFEST 0.16-1/MANIFEST
--- 0.15-3/MANIFEST	2018-04-22 12:17:27.000000000 +0000
+++ 0.16-1/MANIFEST	2024-04-13 13:37:58.000000000 +0000
@@ -1,4 +1,7 @@
+.github/workflows/testsuite.yml
 .gitignore
+.travis.yml
+.whitesource
 Changes
 LICENSE
 MANIFEST
@@ -6,6 +9,8 @@ Makefile.PL
 README
 Random.pm
 Random.xs
+appveyor.cmd
+appveyor.yml
 hints/MSWin32.pl
 t/0-basic.t
 t/z_kwalitee.t
diff -pruN 0.15-3/META.json 0.16-1/META.json
--- 0.15-3/META.json	2018-04-22 12:17:27.000000000 +0000
+++ 0.16-1/META.json	2024-04-13 13:37:58.000000000 +0000
@@ -4,13 +4,13 @@
       "Ian Robertson"
    ],
    "dynamic_config" : 1,
-   "generated_by" : "ExtUtils::MakeMaker version 7.34, CPAN::Meta::Converter version 2.150010",
+   "generated_by" : "ExtUtils::MakeMaker version 7.70, CPAN::Meta::Converter version 2.150010",
    "license" : [
       "perl_5"
    ],
    "meta-spec" : {
       "url" : "http://search.cpan.org/perldoc?CPAN::Meta::Spec",
-      "version" : "2"
+      "version" : 2
    },
    "name" : "Crypt-OpenSSL-Random",
    "no_index" : {
@@ -29,6 +29,12 @@
          "requires" : {
             "Crypt::OpenSSL::Guess" : "0.11"
          }
+      },
+      "test" : {
+         "requires" : {
+            "Test::More" : "0",
+            "Test::Pod" : "1.22"
+         }
       }
    },
    "release_status" : "stable",
@@ -40,6 +46,6 @@
          "url" : "https://github.com/rurban/Crypt-OpenSSL-Random"
       }
    },
-   "version" : "0.15",
-   "x_serialization_backend" : "JSON::PP version 2.27400_02"
+   "version" : "0.16",
+   "x_serialization_backend" : "JSON::PP version 4.16"
 }
diff -pruN 0.15-3/META.yml 0.16-1/META.yml
--- 0.15-3/META.yml	2018-04-22 12:17:26.000000000 +0000
+++ 0.16-1/META.yml	2024-04-13 13:37:58.000000000 +0000
@@ -4,10 +4,12 @@ author:
   - 'Ian Robertson'
 build_requires:
   ExtUtils::MakeMaker: '0'
+  Test::More: '0'
+  Test::Pod: '1.22'
 configure_requires:
   Crypt::OpenSSL::Guess: '0.11'
 dynamic_config: 1
-generated_by: 'ExtUtils::MakeMaker version 7.34, CPAN::Meta::Converter version 2.150010'
+generated_by: 'ExtUtils::MakeMaker version 7.70, CPAN::Meta::Converter version 2.150010'
 license: perl
 meta-spec:
   url: http://module-build.sourceforge.net/META-spec-v1.4.html
@@ -20,5 +22,5 @@ no_index:
 resources:
   license: http://dev.perl.org/licenses/
   repository: https://github.com/rurban/Crypt-OpenSSL-Random
-version: '0.15'
+version: '0.16'
 x_serialization_backend: 'CPAN::Meta::YAML version 0.018'
diff -pruN 0.15-3/Makefile.PL 0.16-1/Makefile.PL
--- 0.15-3/Makefile.PL	2018-04-17 17:29:26.000000000 +0000
+++ 0.16-1/Makefile.PL	2024-04-13 13:31:56.000000000 +0000
@@ -19,7 +19,11 @@ WriteMakefile(
   'LIBS'            => $libdir ? [ "-L$libdir $libs" ] : [ openssl_lib_paths() . " $libs" ],
   'INC'             => $incdir ? "-I$incdir" : openssl_inc_paths(),
   'AUTHOR'          => 'Ian Robertson',
-   (eval { ExtUtils::MakeMaker->VERSION('6.52'); 1 } ?
+  TEST_REQUIRES => {
+    'Test::Pod'           => '1.22',
+    'Test::More'          => 0,
+  },
+  (eval { ExtUtils::MakeMaker->VERSION('6.52'); 1 } ?
     ('CONFIGURE_REQUIRES' =>
      {
       'Crypt::OpenSSL::Guess' => '0.11',
@@ -38,7 +42,7 @@ WriteMakefile(
       },
      }
     ) : ()),
-    SIGN => 1
+    ($ENV{AUTOMATED_TESTING} ? () : (SIGN => 1)),
 );
 
 package MY;
diff -pruN 0.15-3/README 0.16-1/README
--- 0.15-3/README	2018-04-22 12:17:01.000000000 +0000
+++ 0.16-1/README	2024-04-13 13:36:52.000000000 +0000
@@ -17,7 +17,7 @@ DESCRIPTION
     "Crypt::OpenSSL::Random" provides the ability to seed and query the
     OpenSSL and LibreSSL library's pseudo-random number generators.
 
-    Note: On LibreSSL "random_egd()" is not defined.
+    Note: On LibreSSL random_egd() is not defined.
 
   EXPORT
     None by default.
@@ -46,11 +46,12 @@ Static Methods
         on success, or -1 if not enough bytes were read, or if the
         connection to the daemon failed.
 
-        "libressl" considers this function insecure, so with libressl this
-        function does not exist.
+        "libressl" considers this function insecure, so with libressl or an
+        openssl with no-egd this function does not exist.
 
     random_status ()
-        This function returns true if the PRNG has sufficient seeding.
+        This function returns 1 if the PRNG has sufficient seeding. or 0 if
+        not.
 
 BUGS
     Because of the internal workings of OpenSSL's random library, the
diff -pruN 0.15-3/Random.pm 0.16-1/Random.pm
--- 0.15-3/Random.pm	2018-04-22 12:15:46.000000000 +0000
+++ 0.16-1/Random.pm	2024-04-13 13:33:16.000000000 +0000
@@ -9,7 +9,7 @@ require Exporter;
 @EXPORT_OK = qw( random_bytes random_pseudo_bytes random_seed
                  random_egd random_status );
 
-$VERSION = '0.15';
+$VERSION = '0.16';
 XSLoader::load( __PACKAGE__, $VERSION );
 
 1;
@@ -73,12 +73,12 @@ gathering daemon.  Returns the number of
 success, or C<-1> if not enough bytes were read, or if the connection to
 the daemon failed.
 
-C<libressl> considers this function insecure, so with libressl this
-function does not exist.
+C<libressl> considers this function insecure, so with libressl or an openssl with
+no-egd this function does not exist.
 
 =item random_status ()
 
-This function returns true if the PRNG has sufficient seeding.
+This function returns 1 if the PRNG has sufficient seeding. or 0 if not.
 
 =back
 
diff -pruN 0.15-3/Random.xs 0.16-1/Random.xs
--- 0.15-3/Random.xs	2015-10-08 22:07:28.000000000 +0000
+++ 0.16-1/Random.xs	2024-04-13 12:50:11.000000000 +0000
@@ -22,7 +22,7 @@ PPCODE:
             PACKAGE_NAME);
     }
 
-    if(RAND_bytes(rand_bytes, num_bytes))
+    if(RAND_bytes(rand_bytes, num_bytes) == 1)
     {
       XPUSHs(sv_2mortal(newSVpv((const char*)rand_bytes, num_bytes)));
         Safefree(rand_bytes);
@@ -47,7 +47,7 @@ PPCODE:
             PACKAGE_NAME);
     }
 
-    if(RAND_bytes(rand_bytes, num_bytes))
+    if(RAND_bytes(rand_bytes, num_bytes) == 1)
     {
         XPUSHs(sv_2mortal(newSVpv((const char*)rand_bytes, num_bytes)));
         Safefree(rand_bytes);
@@ -77,6 +77,9 @@ PPCODE:
  # Seed the PRNG with data from the indicated EntropyGatheringDaemon;
  # returns the number of bytes gathered, or -1 if there was a
  # connection failure or if the PRNG is still insufficiently seeded.
+ # libressl considers this function insecure, so with libressl or an openssl with
+ # no-egd this function does not exist.
+
 
 #ifndef OPENSSL_NO_EGD
 
@@ -94,7 +97,7 @@ PPCODE:
 
 #endif
 
- # Returns true if the PRNG has enough seed data
+ # Returns 1 if the PRNG has enough seed data
 
 void
 random_status()
diff -pruN 0.15-3/SIGNATURE 0.16-1/SIGNATURE
--- 0.15-3/SIGNATURE	2018-04-22 12:17:28.000000000 +0000
+++ 0.16-1/SIGNATURE	2024-04-13 13:37:59.000000000 +0000
@@ -1,5 +1,5 @@
 This file contains message digests of all files listed in MANIFEST,
-signed via the Module::Signature module, version 0.81.
+signed via the Module::Signature module, version 0.88.
 
 To verify the content in this distribution, first make sure you have
 Module::Signature installed, then type:
@@ -12,29 +12,42 @@ the distribution may already have been c
 not run its Makefile.PL or Build.PL.
 
 -----BEGIN PGP SIGNED MESSAGE-----
-Hash: SHA1
+Hash: RIPEMD160
 
-SHA1 5dd03065ad95845ec70baa4c92c396dc3ef15efb .gitignore
-SHA1 8a4b268576899ecee2db86a9cdf40912a4bdca20 Changes
-SHA1 78f7d31b9283b034cf19e61bc70d24bb38581b1e LICENSE
-SHA1 d1b344f1315cebc307771957afb228ff85a5eb2c MANIFEST
-SHA1 d94d8a01a0b427ee5d3fbd7d23b1b0114f28ae2a META.json
-SHA1 0a6fecb9347012ff3c74f4f00c1150f246a3160b META.yml
-SHA1 952c5a7ab166bbb84b083194b58ad938acc9d488 Makefile.PL
-SHA1 adde4138362d420b3262fa08289190ab1de3dbe7 README
-SHA1 640247ce0d22fc286c9bc6cf54aa4cc7933257cc Random.pm
-SHA1 96741e2c68170512e8fc38829466d1e041c3a3ec Random.xs
-SHA1 f3b7242c48c8d393b6c5803d8502e7e22c03818d hints/MSWin32.pl
-SHA1 fa94838ecdaeccd2bf162caf7014a624dc1e66a7 t/0-basic.t
-SHA1 7de5e8f63465d9711faa107972ebce8e1349ccd6 t/z_kwalitee.t
-SHA1 9eba44de180daef6319b2c4a75ab55c972844c0e t/z_manifest.t
-SHA1 993b3cef8c06a70d99829facf76140864eb57240 t/z_meta.t
-SHA1 ade48e2b6098a0a329312543e1451e7e7fb7bc5f t/z_perl_minimum_version.t
-SHA1 1dbe44e2091ab84d8462fda2052e35bf1354d963 t/z_pod-coverage.t
-SHA1 c8aa3903d3aba84c19bbd94d677620c758fa07d5 t/z_pod.t
+SHA256 78734be2fd64b3c9ca8c40db1861895403495e93c9476835cdf8946f97ec71aa .github/workflows/testsuite.yml
+SHA256 e0d05de18199a94908b401b173c6a4ec14d4e3650cbc41975b29d39a7a2796bc .gitignore
+SHA256 fc9ee1aef1ec37a4f9b403d47094187013d2c33cae494a94719470719bcd7848 .travis.yml
+SHA256 c3f2a1a4f66382f796f71a571946722edba53cf3238152b26fd325f4c2f1a20f .whitesource
+SHA256 d3accc700653136525b57ab67110ab44aca44c928e00d24a34318a5dd4502fec Changes
+SHA256 fdaba2134145d3e252c5930180b2bcb13b5367ad5a8713d6868f014cd25c496f LICENSE
+SHA256 38e24f7777fc8f636eee157babf8a7784216795d319da08e25b5ed5091646d2f MANIFEST
+SHA256 6d92125b3a6dfa00b15221b53502de0164aac117f2f834ea45c5d19abec8cbf7 META.json
+SHA256 633244006b71e21a580d177384d9b52d4f0caa882347efa8c6b20c1ed395193c META.yml
+SHA256 9c6bbc9b6d35ab84bc223dfdec0b13774ed5f03920679b532eabecc19dda8848 Makefile.PL
+SHA256 afc51dab1b2513ff0f51003c108bf109134cf3ba222e20c49c0bab39eea702c3 README
+SHA256 229087bf80a4a8bf8d9856ad7d6dbd2e501baf563533f777429e779f8be7133a Random.pm
+SHA256 c10331bd4f984729cb0b5adbbc34fe80059c277ea7dac97cc46276461b437647 Random.xs
+SHA256 8ffe6bd0903b8546335dd145c77a48b276f2d9d463935d20e521c48dacd4d4d9 appveyor.cmd
+SHA256 a14b05a479c13feeb788aec47d5f64b210f5a6441d1b8d1bff94d71fe93d68a3 appveyor.yml
+SHA256 4bd33ae329602f9e83894c16a0a8b43e4135e0fa998654c0077f18eff12d3334 hints/MSWin32.pl
+SHA256 3ab268559e67af918eddde0846a1fe50e8e84a82dbd33a92b8a9297e359894ba t/0-basic.t
+SHA256 ee525516faef913dacd961b10e4eb5269d44a56e13d15f338fb1c1d010ef1f27 t/z_kwalitee.t
+SHA256 5d40f24706e30f55f338163b7d73b29dea221c22a6be3b295f0449cbb6c5eb11 t/z_manifest.t
+SHA256 fb00e0e0d57de606699706d2a2e486df05d840793d3bcf6e4bb13f1604f19487 t/z_meta.t
+SHA256 956f858cc6c609d57ad5f92b6432a40c9c3d90576c397f90afa4489d12030850 t/z_perl_minimum_version.t
+SHA256 686044dda7ffe5f456c4f0313cb0dc1dc9a4bc0f6b80d77d404582580098702c t/z_pod-coverage.t
+SHA256 298e9a5d4190701d4438f3f68c1e44139cfa36982503ccc44572d04cfe3c317a t/z_pod.t
 -----BEGIN PGP SIGNATURE-----
 
-iF0EARECAB0WIQRZHhhUcL58V8z0UW2abZJij/3JQgUCWtx9VwAKCRCabZJij/3J
-QhYZAJ4+84dWP+yDFoHPgGav+N8aEd24RQCeKkgjjC8PDobdCOmJhmZkRoph0B8=
-=JBj5
+iQGzBAEBAwAdFiEEOKQWew22nknF9yFsuMKIZqsnp6IFAmYaircACgkQuMKIZqsn
+p6KZHAwAg2igmEY+lSL+DE+EfZ5UFTS1vajH2Le3+3u4iucbonAcme3/PQzAkML+
+/mb1SYmnVhDeAFcQ/Pm8cNDhM6lXx3jIdiFgJXPToEYUHZZHXnLxLOn5B0w7fT/g
+UtyfmzExVhVZ1l52L98b4AyWCRdB1Mqjg6SqS2XfZGaRXvEOnaQrnLm04IhFK6pK
+vPt0TZM44UZN7h0fPn4UzeguyymCfrO43vMRoCY8LfCTm4t32kKvqmkZL5CQeWbo
+ZnJqq5veNiU5Ur2lPtMKaAkyu65Fkas2wDHU1tpRSYM4taNmHfeDJXT6UJNDyTkE
+0bufGZZL4PLpwHwvngGm9RrY43yXFFt4tqj53VG50pbt39vLXPVz4s5CaDDDk6MF
+/ukHJwXog+tI3CrCmGepWuwSGlJvWjiAyhpfeMAK58Ya3CRKtUh70ZxBbV7PJJ/I
+Ep+SFDpaHWdA7JKxWZPwNf6+2BEV/UdoZ0bZfhu1k6t5x7zkrO2N0jFxwEm2lGah
+ik5txD7y
+=+gEY
 -----END PGP SIGNATURE-----
diff -pruN 0.15-3/appveyor.cmd 0.16-1/appveyor.cmd
--- 0.15-3/appveyor.cmd	1970-01-01 00:00:00.000000000 +0000
+++ 0.16-1/appveyor.cmd	2024-04-12 16:58:52.000000000 +0000
@@ -0,0 +1,71 @@
+@echo off
+call :%*
+goto :eof
+
+:perl_setup
+if not defined perl_type set perl_type=system
+if "%perl_type%" == "cygwin" (
+  start /wait c:\cygwin\setup-x86.exe -q -g -P perl -P make -P gcc -P gcc-g++ -P libcrypt-devel
+  set "PATH=C:\cygwin\usr\local\bin;C:\cygwin\bin;%PATH%"
+) else if "%perl_type%" == "strawberry" (
+  if not defined perl_version (
+    cinst -y StrawberryPerl
+  ) else (
+    cinst -y StrawberryPerl --version %perl_version%
+  )
+  if errorlevel 1 (
+    type C:\ProgramData\chocolatey\logs\chocolatey.log
+    exit /b 1
+  )
+  set "PATH=C:\Strawberry\perl\site\bin;C:\Strawberry\perl\bin;C:\Strawberry\c\bin;%PATH%"
+) else if "%perl_type%" == "system" (
+  mkdir c:\dmake
+  cinst -y curl
+  curl http://www.cpan.org/authors/id/S/SH/SHAY/dmake-4.12.2.2.zip -o c:\dmake\dmake.zip
+  7z x c:\dmake\dmake.zip -oc:\ >NUL
+  set "PATH=c:\dmake;C:\MinGW\bin;%PATH%"
+) else (
+  echo.Unknown perl type "%perl_type%"! 1>&2
+  exit /b 1
+)
+for /f "usebackq delims=" %%d in (`perl -MConfig -e"print $Config{make}"`) do set "make=%%d"
+set "perl=perl"
+set "cpanm=call appveyor.cmd cpanm"
+set "cpan=%perl% -S cpan"
+set TAR_OPTIONS=--warning=no-unknown-keyword
+goto :eof
+
+:cpanm
+%perl% -S cpanm >NUL 2>&1
+if ERRORLEVEL 1 (
+  curl -V >NUL 2>&1
+  if ERRORLEVEL 1 cinst -y curl
+  curl -k -L https://cpanmin.us/ -o "%TEMP%\cpanm"
+  %perl% "%TEMP%\cpanm" -n App::cpanminus
+)
+set "cpanm=%perl% -S cpanm"
+%cpanm% %*
+goto :eof
+
+:local_lib
+if "%perl_type%" == "cygwin" goto :local_lib_cygwin
+%perl% -Ilib -Mlocal::lib=--shelltype=cmd %* > %TEMP%\local-lib.bat
+call %TEMP%\local-lib.bat
+del %TEMP%\local-lib.bat
+goto :eof
+
+:local_lib_cygwin
+for /f "usebackq delims=" %%d in (`sh -c "cygpath -w $HOME/perl5"`) do (
+  c:\perl\bin\perl.exe -Ilib -Mlocal::lib - %%d --shelltype=cmd > "%TEMP%\local-lib.bat"
+)
+setlocal
+  call "%TEMP%\local-lib.bat"
+endlocal & set "PATH=%PATH%"
+set "PATH_BACK=%PATH%"
+%perl% -Ilib -Mlocal::lib - --shelltype=cmd > "%TEMP%\local-lib.bat"
+call "%TEMP%\local-lib.bat"
+set "PATH=%PATH_BACK%"
+del "%TEMP%\local-lib.bat"
+goto :eof
+
+:eof
diff -pruN 0.15-3/appveyor.yml 0.16-1/appveyor.yml
--- 0.15-3/appveyor.yml	1970-01-01 00:00:00.000000000 +0000
+++ 0.16-1/appveyor.yml	2024-04-12 16:58:52.000000000 +0000
@@ -0,0 +1,33 @@
+version: '{build}'
+shallow_clone: true
+
+environment:
+  matrix:
+    - perl_type: system
+    - perl_type: cygwin
+    - perl_type: strawberry
+    - perl_type: strawberry
+      perl_version: 5.24.3.1
+    - perl_type: strawberry
+      perl_version: 5.20.3.3
+    - perl_type: strawberry
+      perl_version: 5.18.4.1
+install:
+  # use strawberry perl's OpenSSL, remove AppVeyor's buildin OpenSSL-Win32
+  - cmd: if [%perl_type%]==[strawberry] (
+      rd /s /q C:\OpenSSL-Win32 )
+  - cmd: if [%perl_type%]==[cygwin] (
+      C:\cygwin\setup-x86.exe -qgnNdO -l C:\cygwin\var\cache\setup -R c:\cygwin -s http://cygwin.mirror.constant.com -P openssl-devel )
+
+  - 'call appveyor.cmd perl_setup'
+  - '%perl% -V'
+  - '%cpanm% -n Crypt::OpenSSL::Guess'
+  - '%cpanm% --installdeps -n --with-develop --with-recommends .'
+
+build: off
+
+test_script:
+  - '%perl% Makefile.PL && %make% test'
+
+matrix:
+ fast_finish: true
diff -pruN 0.15-3/debian/changelog 0.16-1/debian/changelog
--- 0.15-3/debian/changelog	2022-09-10 21:27:11.000000000 +0000
+++ 0.16-1/debian/changelog	2024-04-19 17:25:21.000000000 +0000
@@ -1,3 +1,14 @@
+libcrypt-openssl-random-perl (0.16-1) unstable; urgency=medium
+
+  * Team upload.
+  * Import upstream version 0.16.
+  * Update years of packaging copyright.
+  * Declare compliance with Debian Policy 4.7.0.
+  * Use secure URI in Homepage field.
+  * Update test dependencies.
+
+ -- gregor herrmann <gregoa@debian.org>  Fri, 19 Apr 2024 19:25:21 +0200
+
 libcrypt-openssl-random-perl (0.15-3) unstable; urgency=medium
 
   * Team upload.
diff -pruN 0.15-3/debian/control 0.16-1/debian/control
--- 0.15-3/debian/control	2022-09-10 21:27:11.000000000 +0000
+++ 0.16-1/debian/control	2024-04-19 17:25:21.000000000 +0000
@@ -7,12 +7,13 @@ Priority: optional
 Build-Depends: debhelper-compat (= 13),
                libcrypt-openssl-guess-perl,
                libssl-dev,
+               libtest-simple-perl <!nocheck>,
                perl-xs-dev,
                perl:native
-Standards-Version: 4.6.1
+Standards-Version: 4.7.0
 Vcs-Browser: https://salsa.debian.org/perl-team/modules/packages/libcrypt-openssl-random-perl
 Vcs-Git: https://salsa.debian.org/perl-team/modules/packages/libcrypt-openssl-random-perl.git
-Homepage: http://perl-openssl.sourceforge.net/
+Homepage: https://perl-openssl.sourceforge.net/
 Rules-Requires-Root: no
 
 Package: libcrypt-openssl-random-perl
diff -pruN 0.15-3/debian/copyright 0.16-1/debian/copyright
--- 0.15-3/debian/copyright	2022-09-10 21:27:11.000000000 +0000
+++ 0.16-1/debian/copyright	2024-04-19 17:25:21.000000000 +0000
@@ -13,7 +13,7 @@ Comment: The upstream distribution does
 
 Files: debian/*
 Copyright: 2006, Luk Claes <luk@debian.org>
- 2008-2022, gregor herrmann <gregoa@debian.org>
+ 2008-2024, gregor herrmann <gregoa@debian.org>
  2008, Damyan Ivanov <dmn@debian.org>
 License: Artistic or GPL-1+
 
diff -pruN 0.15-3/debian/patches/auto-gitignore 0.16-1/debian/patches/auto-gitignore
--- 0.15-3/debian/patches/auto-gitignore	1970-01-01 00:00:00.000000000 +0000
+++ 0.16-1/debian/patches/auto-gitignore	2024-04-19 17:25:21.000000000 +0000
@@ -0,0 +1,34 @@
+Subject: Update .gitignore from Debian packaging branch
+
+The Debian packaging git branch contains these updates to the upstream
+.gitignore file(s).  This patch is autogenerated, to provide these
+updates to users of the official Debian archive view of the package.
+
+[dgit (11.8) update-gitignore]
+---
+diff --git a/.gitignore b/.gitignore
+deleted file mode 100644
+index 9b9a61d..0000000
+--- a/.gitignore
++++ /dev/null
+@@ -1,20 +0,0 @@
+-.cvsignore
+-blib
+-pm_to_blib
+-Makefile
+-Makefile.old
+-*.bs
+-*.c
+-*.i
+-*.o
+-*.gcov
+-*.gcno
+-cover_db
+-/Debian_CPANTS.txt
+-/00*.patch
+-/log.test-*
+-/Crypt-OpenSSL-Random*.tar.gz
+-/META.yml
+-/MYMETA.yml
+-/MYMETA.json
+-/CVS
diff -pruN 0.15-3/debian/patches/series 0.16-1/debian/patches/series
--- 0.15-3/debian/patches/series	2022-09-10 21:27:11.000000000 +0000
+++ 0.16-1/debian/patches/series	2024-04-19 17:25:21.000000000 +0000
@@ -1 +1,2 @@
 Makefile.PL-no-ssl-in-LIBS.patch
+auto-gitignore
diff -pruN 0.15-3/hints/MSWin32.pl 0.16-1/hints/MSWin32.pl
--- 0.15-3/hints/MSWin32.pl	2018-04-22 12:15:31.000000000 +0000
+++ 0.16-1/hints/MSWin32.pl	2024-04-13 13:01:39.000000000 +0000
@@ -1,9 +1,12 @@
 use Config;
+use Crypt::OpenSSL::Guess 0.11 qw(openssl_lib_paths);
+# openssl <1.1 API on windows: -lssl32 -leay32
+# >= 1.1 API cleanup:          -lssl -lcrypto
 if (my $libs = `pkg-config --libs libssl libcrypto 2>nul`) {
   # strawberry perl has pkg-config
-  $self->{LIBS} = [ $libs ];
+  $self->{LIBS} = [openssl_lib_paths() . " $libs"];
 }
 else {
-  $self->{LIBS} = ['-lssleay32 -llibeay32'] if $Config{cc} =~ /cl/; # msvc with ActivePerl
-  $self->{LIBS} = ['-lssl32 -leay32']       if $Config{gccversion}; # gcc
+  $self->{LIBS} = [openssl_lib_paths() . '-lssleay32 -llibeay32'] if $Config{cc} =~ /cl/; # msvc with ActivePerl
+  $self->{LIBS} = [openssl_lib_paths() . '-lssl32 -leay32']       if $Config{gccversion}; # gcc
 }
diff -pruN 0.15-3/t/z_pod-coverage.t 0.16-1/t/z_pod-coverage.t
--- 0.15-3/t/z_pod-coverage.t	2015-02-04 11:14:13.000000000 +0000
+++ 0.16-1/t/z_pod-coverage.t	2024-04-12 16:58:52.000000000 +0000
@@ -3,7 +3,10 @@ use strict;
 use warnings;
 use Test::More;
 
-plan skip_all => 'done_testing requires Test::More 0.88' if Test::More->VERSION < 0.88;
+BEGIN {
+    plan skip_all => 'done_testing requires Test::More 0.88' if Test::More->VERSION < 0.88;
+}
+
 plan skip_all => 'This test is only run for the module author'
     unless -d '.git' || $ENV{IS_MAINTAINER};
 
